
reset
set terminal postscript enhanced color
set output 'freqnoise.ps'

clp(f,f0) = 1/(1+{0,1}*f/f0)
lp(f,f0) = 1/sqrt(1+f**2/f0**2)

nan = sqrt(-1)
req_freq(f) = (f<0.1) ? nan : (f<0.4) ? 1000 : (f<1) ? 100 : (f<10) ? 3 : (f<20) ? 1 : (f<1000) ? 20/f : (f<10000) ? 2e-2 : nan
req_npro(f) = 10e3/f

db(x)=20.*log10(abs(x))
dbm(x) = 10**((x+10*log10(50.)-30)/20.) # dbm to volt
dbv(x) = 10**(x/20.)    # dbV to volt

set samples 1000

set title 'In-loop, residual frequency noise'

set logscale xy
set xlabel 'frequency (Hz)'
set format x "%.0s%c"
set ylabel 'frequency noise (Hz Hz^{-1/2})'
set format y "10^{%T}" # "%.0te%T"
set grid x y mx my
set mxtics 10
set mytics 10
set key right top 
set style data lines

# used calibration of 45uV/Hz from E02
# used 29.4kHz lowpass from j)
cali=8.84e-5

plot [:100e3] \
	req_npro(x) title 'NPRO expected' lc 3, \
	'SRS001.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) title 'Error point noise' w l lt 1 lc 1,\
 'SRS002.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 1,\
 'SRS004.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 1,\
 'SRS005.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 1,\
 'SRS006.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 1,\
 'SRS100.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) title 'electronic noise' w l lt 1 lc 2,\
 'SRS101.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 2,\
 'SRS102.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 2,\
 'SRS103.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 2,\
 'SRS104.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 2,\
 'SRS105.DAT' u 1:($2/cali/lp($1,29443)*dbv(-10.)) notitle w l lt 1 lc 2, \
	req_freq(x) title 'requirement' lw 2

system('epstopdf --autorotate=All freqnoise.ps')